==> gsequencer_3.2.13.orig.tar.gz: gsequencer-3.2.13/ags/server/controller/ags_front_controller.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2019 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_FRONT_CONTROLLER_H__
#define __AGS_FRONT_CONTROLLER_H__

#include <glib.h>
#include <glib-object.h>

#include <gio/gio.h>

#include <libsoup/soup.h>

#include <ags/server/controller/ags_controller.h>

G_BEGIN_DECLS

#define AGS_TYPE_FRONT_CONTROLLER                (ags_front_controller_get_type())
#define AGS_FRONT_CONTROLLER(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_FRONT_CONTROLLER, AgsFrontController))
#define AGS_FRONT_CONTROLLER_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST(class, AGS_TYPE_FRONT_CONTROLLER, AgsFrontControllerClass))
#define AGS_IS_FRONT_CONTROLLER(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AGS_TYPE_FRONT_CONTROLLER))
#define AGS_IS_FRONT_CONTROLLER_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE ((class), AGS_TYPE_FRONT_CONTROLLER))
#define AGS_FRONT_CONTROLLER_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS(obj, AGS_TYPE_FRONT_CONTROLLER, AgsFrontControllerClass))

typedef struct _AgsFrontController AgsFrontController;
typedef struct _AgsFrontControllerClass AgsFrontControllerClass;

struct _AgsFrontController
{
  AgsController controller;
};

struct _AgsFrontControllerClass
{
  AgsControllerClass controller;

  gpointer (*do_request)(AgsFrontController *front_controller,
			 SoupMessage *msg,
			 GHashTable *query,
			 SoupClientContext *client,
			 GObject *security_context,
			 gchar *path,
			 gchar *login,
			 gchar *security_token);
};

GType ags_front_controller_get_type();

gpointer ags_front_controller_do_request(AgsFrontController *front_controller,
					 SoupMessage *msg,
					 GHashTable *query,
					 SoupClientContext *client,
					 GObject *security_context,
					 gchar *path,
					 gchar *login,
					 gchar *security_token);

AgsFrontController* ags_front_controller_new();

G_END_DECLS

#endif /*__AGS_FRONT_CONTROLLER_H__*/

==> gsequencer_7.7.5.orig.tar.gz: gsequencer-7.7.5/ags/server/controller/ags_front_controller.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2019 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_FRONT_CONTROLLER_H__
#define __AGS_FRONT_CONTROLLER_H__

#include <glib.h>
#include <glib-object.h>

#include <gio/gio.h>

#include <libsoup/soup.h>

#include <ags/server/controller/ags_controller.h>

G_BEGIN_DECLS

#define AGS_TYPE_FRONT_CONTROLLER                (ags_front_controller_get_type())
#define AGS_FRONT_CONTROLLER(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_FRONT_CONTROLLER, AgsFrontController))
#define AGS_FRONT_CONTROLLER_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST(class, AGS_TYPE_FRONT_CONTROLLER, AgsFrontControllerClass))
#define AGS_IS_FRONT_CONTROLLER(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AGS_TYPE_FRONT_CONTROLLER))
#define AGS_IS_FRONT_CONTROLLER_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE ((class), AGS_TYPE_FRONT_CONTROLLER))
#define AGS_FRONT_CONTROLLER_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS(obj, AGS_TYPE_FRONT_CONTROLLER, AgsFrontControllerClass))

typedef struct _AgsFrontController AgsFrontController;
typedef struct _AgsFrontControllerClass AgsFrontControllerClass;

struct _AgsFrontController
{
  AgsController controller;
};

struct _AgsFrontControllerClass
{
  AgsControllerClass controller;

  gpointer (*do_request)(AgsFrontController *front_controller,
			 SoupServerMessage *msg,
			 GHashTable *query,
			 GObject *security_context,
			 gchar *path,
			 gchar *login,
			 gchar *security_token);
};

GType ags_front_controller_get_type();

gpointer ags_front_controller_do_request(AgsFrontController *front_controller,
					 SoupServerMessage *msg,
					 GHashTable *query,
					 GObject *security_context,
					 gchar *path,
					 gchar *login,
					 gchar *security_token);

AgsFrontController* ags_front_controller_new();

G_END_DECLS

#endif /*__AGS_FRONT_CONTROLLER_H__*/
